@@ -1,3 +1,23 @@
+#  Copyright (c) 2023 SIMBA Chain Inc. https://simbachain.com
+#
+#  Permission is hereby granted, free of charge, to any person obtaining a copy
+#  of this software and associated documentation files (the "Software"), to deal
+#  in the Software without restriction, including without limitation the rights
+#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+#  copies of the Software, and to permit persons to whom the Software is
+#  furnished to do so, subject to the following conditions:
+#
+#  The above copyright notice and this permission notice shall be included in
+#  all copies or substantial portions of the Software.
+#
+#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+#  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+#  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+#  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+#  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+#  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+#  THE SOFTWARE.
+
 import base64
 import logging
 import time
@@ -615,7 +635,6 @@ class Simba(SimbaSync):
         full["app_name"] = app
         if args:
             full["args"] = args
-        full["singleton"] = True
         return await PostRequest(
             endpoint=Path.DESIGN_DEPLOY.format(org, design_id),
             login=login,
@@ -646,7 +665,6 @@ class Simba(SimbaSync):
         full["app_name"] = app
         if args:
             full["args"] = args
-        full["singleton"] = True
         return await PostRequest(
             endpoint=Path.DEPLOYMENTS.format(org),
             login=login,
